@@ -1,120 +1,138 @@
-( cd opt/kde/lib ; rm -rf libnepomuk.so )
-( cd opt/kde/lib ; ln -sf libnepomuk.so.4 libnepomuk.so )
-( cd opt/kde/lib ; rm -rf libkparts.so )
-( cd opt/kde/lib ; ln -sf libkparts.so.4 libkparts.so )
-( cd opt/kde/lib ; rm -rf libkjsembed.so )
-( cd opt/kde/lib ; ln -sf libkjsembed.so.4 libkjsembed.so )
-( cd opt/kde/lib ; rm -rf libthreadweaver.so.4 )
-( cd opt/kde/lib ; ln -sf libthreadweaver.so.4.1.0 libthreadweaver.so.4 )
-( cd opt/kde/lib/kde4/plugins/script ; rm -rf libkrossqtsplugin.so )
-( cd opt/kde/lib/kde4/plugins/script ; ln -sf libkrossqtsplugin.so.4 libkrossqtsplugin.so )
-( cd opt/kde/lib/kde4/plugins/script ; rm -rf libkrossqtsplugin.so.4 )
-( cd opt/kde/lib/kde4/plugins/script ; ln -sf libkrossqtsplugin.so.4.1.0 libkrossqtsplugin.so.4 )
 ( cd opt/kde/lib/kde4/libexec ; rm -rf filesharelist )
 ( cd opt/kde/lib/kde4/libexec ; ln -sf /opt/kde/lib/kde4/libexec/fileshareset filesharelist )
+( cd opt/kde/lib/kde4/plugins/script ; rm -rf libkrossqtsplugin.so.4 )
+( cd opt/kde/lib/kde4/plugins/script ; ln -sf libkrossqtsplugin.so.4.2.0 libkrossqtsplugin.so.4 )
+( cd opt/kde/lib/kde4/plugins/script ; rm -rf libkrossqtsplugin.so )
+( cd opt/kde/lib/kde4/plugins/script ; ln -sf libkrossqtsplugin.so.4 libkrossqtsplugin.so )
 ( cd opt/kde/lib ; rm -rf libknewstuff2.so )
 ( cd opt/kde/lib ; ln -sf libknewstuff2.so.4 libknewstuff2.so )
-( cd opt/kde/lib ; rm -rf libkrossui.so )
-( cd opt/kde/lib ; ln -sf libkrossui.so.4 libkrossui.so )
-( cd opt/kde/lib ; rm -rf libktexteditor.so.4 )
-( cd opt/kde/lib ; ln -sf libktexteditor.so.4.1.0 libktexteditor.so.4 )
-( cd opt/kde/lib ; rm -rf libkutils.so.4 )
-( cd opt/kde/lib ; ln -sf libkutils.so.4.1.0 libkutils.so.4 )
-( cd opt/kde/lib ; rm -rf libknotifyconfig.so )
-( cd opt/kde/lib ; ln -sf libknotifyconfig.so.4 libknotifyconfig.so )
-( cd opt/kde/lib ; rm -rf libkio.so.5 )
-( cd opt/kde/lib ; ln -sf libkio.so.5.1.0 libkio.so.5 )
-( cd opt/kde/lib ; rm -rf libthreadweaver.so )
-( cd opt/kde/lib ; ln -sf libthreadweaver.so.4 libthreadweaver.so )
-( cd opt/kde/lib ; rm -rf libkdeui.so )
-( cd opt/kde/lib ; ln -sf libkdeui.so.5 libkdeui.so )
+( cd opt/kde/lib ; rm -rf libkdesu.so.5 )
+( cd opt/kde/lib ; ln -sf libkdesu.so.5.2.0 libkdesu.so.5 )
+( cd opt/kde/lib ; rm -rf libkio.so )
+( cd opt/kde/lib ; ln -sf libkio.so.5 libkio.so )
 ( cd opt/kde/lib ; rm -rf libkjs.so )
 ( cd opt/kde/lib ; ln -sf libkjs.so.4 libkjs.so )
+( cd opt/kde/lib ; rm -rf libthreadweaver.so )
+( cd opt/kde/lib ; ln -sf libthreadweaver.so.4 libthreadweaver.so )
 ( cd opt/kde/lib ; rm -rf libknewstuff2.so.4 )
-( cd opt/kde/lib ; ln -sf libknewstuff2.so.4.1.0 libknewstuff2.so.4 )
-( cd opt/kde/lib ; rm -rf libsolid.so )
-( cd opt/kde/lib ; ln -sf libsolid.so.4 libsolid.so )
-( cd opt/kde/lib ; rm -rf libkntlm.so )
-( cd opt/kde/lib ; ln -sf libkntlm.so.4 libkntlm.so )
-( cd opt/kde/lib ; rm -rf libsolid.so.4 )
-( cd opt/kde/lib ; ln -sf libsolid.so.4.1.0 libsolid.so.4 )
-( cd opt/kde/lib ; rm -rf libkparts.so.4 )
-( cd opt/kde/lib ; ln -sf libkparts.so.4.1.0 libkparts.so.4 )
-( cd opt/kde/lib ; rm -rf libkrosscore.so )
-( cd opt/kde/lib ; ln -sf libkrosscore.so.4 libkrosscore.so )
-( cd opt/kde/lib ; rm -rf libkmediaplayer.so )
-( cd opt/kde/lib ; ln -sf libkmediaplayer.so.4 libkmediaplayer.so )
-( cd opt/kde/lib ; rm -rf libkunittest.so.4 )
-( cd opt/kde/lib ; ln -sf libkunittest.so.4.1.0 libkunittest.so.4 )
-( cd opt/kde/lib ; rm -rf libkdefakes.so.5 )
-( cd opt/kde/lib ; ln -sf libkdefakes.so.5.1.0 libkdefakes.so.5 )
-( cd opt/kde/lib ; rm -rf libkjs.so.4 )
-( cd opt/kde/lib ; ln -sf libkjs.so.4.1.0 libkjs.so.4 )
-( cd opt/kde/lib ; rm -rf libkunittest.so )
-( cd opt/kde/lib ; ln -sf libkunittest.so.4 libkunittest.so )
-( cd opt/kde/lib ; rm -rf libkfile.so )
-( cd opt/kde/lib ; ln -sf libkfile.so.4 libkfile.so )
-( cd opt/kde/lib ; rm -rf libkimproxy.so.4 )
-( cd opt/kde/lib ; ln -sf libkimproxy.so.4.1.0 libkimproxy.so.4 )
+( cd opt/kde/lib ; ln -sf libknewstuff2.so.4.2.0 libknewstuff2.so.4 )
 ( cd opt/kde/lib ; rm -rf libkrossui.so.4 )
-( cd opt/kde/lib ; ln -sf libkrossui.so.4.1.0 libkrossui.so.4 )
-( cd opt/kde/lib ; rm -rf libkntlm.so.4 )
-( cd opt/kde/lib ; ln -sf libkntlm.so.4.1.0 libkntlm.so.4 )
-( cd opt/kde/lib ; rm -rf libnepomuk.so.4 )
-( cd opt/kde/lib ; ln -sf libnepomuk.so.4.1.0 libnepomuk.so.4 )
+( cd opt/kde/lib ; ln -sf libkrossui.so.4.2.0 libkrossui.so.4 )
+( cd opt/kde/lib ; rm -rf libkparts.so )
+( cd opt/kde/lib ; ln -sf libkparts.so.4 libkparts.so )
+( cd opt/kde/lib ; rm -rf libkutils.so.4 )
+( cd opt/kde/lib ; ln -sf libkutils.so.4.2.0 libkutils.so.4 )
+( cd opt/kde/lib ; rm -rf libkrossui.so )
+( cd opt/kde/lib ; ln -sf libkrossui.so.4 libkrossui.so )
+( cd opt/kde/lib ; rm -rf libknotifyconfig.so )
+( cd opt/kde/lib ; ln -sf libknotifyconfig.so.4 libknotifyconfig.so )
+( cd opt/kde/lib ; rm -rf libkjs.so.4 )
+( cd opt/kde/lib ; ln -sf libkjs.so.4.2.0 libkjs.so.4 )
+( cd opt/kde/lib ; rm -rf libkdeui.so.5 )
+( cd opt/kde/lib ; ln -sf libkdeui.so.5.2.0 libkdeui.so.5 )
 ( cd opt/kde/lib ; rm -rf libkimproxy.so )
 ( cd opt/kde/lib ; ln -sf libkimproxy.so.4 libkimproxy.so )
 ( cd opt/kde/lib ; rm -rf libkdesu.so )
 ( cd opt/kde/lib ; ln -sf libkdesu.so.5 libkdesu.so )
-( cd opt/kde/lib ; rm -rf libkdecore.so )
-( cd opt/kde/lib ; ln -sf libkdecore.so.5 libkdecore.so )
-( cd opt/kde/lib ; rm -rf libkdeui.so.5 )
-( cd opt/kde/lib ; ln -sf libkdeui.so.5.1.0 libkdeui.so.5 )
-( cd opt/kde/lib ; rm -rf libktexteditor.so )
-( cd opt/kde/lib ; ln -sf libktexteditor.so.4 libktexteditor.so )
-( cd opt/kde/lib ; rm -rf libkdnssd.so )
-( cd opt/kde/lib ; ln -sf libkdnssd.so.4 libkdnssd.so )
+( cd opt/kde/lib ; rm -rf libkdeui.so )
+( cd opt/kde/lib ; ln -sf libkdeui.so.5 libkdeui.so )
+( cd opt/kde/lib ; rm -rf libkdnssd.so.4 )
+( cd opt/kde/lib ; ln -sf libkdnssd.so.4.2.0 libkdnssd.so.4 )
+( cd opt/kde/lib ; rm -rf libkdecore.so.5 )
+( cd opt/kde/lib ; ln -sf libkdecore.so.5.2.0 libkdecore.so.5 )
+( cd opt/kde/lib ; rm -rf libthreadweaver.so.4 )
+( cd opt/kde/lib ; ln -sf libthreadweaver.so.4.2.0 libthreadweaver.so.4 )
+( cd opt/kde/lib ; rm -rf libnepomuk.so.4 )
+( cd opt/kde/lib ; ln -sf libnepomuk.so.4.2.0 libnepomuk.so.4 )
+( cd opt/kde/lib ; rm -rf libkfile.so.4 )
+( cd opt/kde/lib ; ln -sf libkfile.so.4.2.0 libkfile.so.4 )
+( cd opt/kde/lib ; rm -rf libkjsembed.so )
+( cd opt/kde/lib ; ln -sf libkjsembed.so.4 libkjsembed.so )
+( cd opt/kde/lib ; rm -rf libkhtml.so.5 )
+( cd opt/kde/lib ; ln -sf libkhtml.so.5.2.0 libkhtml.so.5 )
 ( cd opt/kde/lib ; rm -rf libkjsembed.so.4 )
-( cd opt/kde/lib ; ln -sf libkjsembed.so.4.1.0 libkjsembed.so.4 )
-( cd opt/kde/lib ; rm -rf libkwalletbackend.so )
-( cd opt/kde/lib ; ln -sf libkwalletbackend.so.4 libkwalletbackend.so )
-( cd opt/kde/lib ; rm -rf libkdesu.so.5 )
-( cd opt/kde/lib ; ln -sf libkdesu.so.5.1.0 libkdesu.so.5 )
-( cd opt/kde/lib ; rm -rf libkwalletbackend.so.4 )
-( cd opt/kde/lib ; ln -sf libkwalletbackend.so.4.1.0 libkwalletbackend.so.4 )
-( cd opt/kde/lib ; rm -rf libkhtml.so )
-( cd opt/kde/lib ; ln -sf libkhtml.so.5 libkhtml.so )
-( cd opt/kde/lib ; rm -rf libkdefakes.so )
-( cd opt/kde/lib ; ln -sf libkdefakes.so.5 libkdefakes.so )
-( cd opt/kde/lib ; rm -rf libkde3support.so.4 )
-( cd opt/kde/lib ; ln -sf libkde3support.so.4.1.0 libkde3support.so.4 )
-( cd opt/kde/lib ; rm -rf libkutils.so )
-( cd opt/kde/lib ; ln -sf libkutils.so.4 libkutils.so )
-( cd opt/kde/lib ; rm -rf libkrosscore.so.4 )
-( cd opt/kde/lib ; ln -sf libkrosscore.so.4.1.0 libkrosscore.so.4 )
+( cd opt/kde/lib ; ln -sf libkjsembed.so.4.2.0 libkjsembed.so.4 )
+( cd opt/kde/lib ; rm -rf libkunittest.so.4 )
+( cd opt/kde/lib ; ln -sf libkunittest.so.4.2.0 libkunittest.so.4 )
+( cd opt/kde/lib ; rm -rf libnepomuk.so )
+( cd opt/kde/lib ; ln -sf libnepomuk.so.4 libnepomuk.so )
+( cd opt/kde/lib ; rm -rf libkjsapi.so.4 )
+( cd opt/kde/lib ; ln -sf libkjsapi.so.4.2.0 libkjsapi.so.4 )
 ( cd opt/kde/lib ; rm -rf libkde3support.so )
 ( cd opt/kde/lib ; ln -sf libkde3support.so.4 libkde3support.so )
-( cd opt/kde/lib ; rm -rf libkpty.so.4 )
-( cd opt/kde/lib ; ln -sf libkpty.so.4.1.0 libkpty.so.4 )
-( cd opt/kde/lib ; rm -rf libkmediaplayer.so.4 )
-( cd opt/kde/lib ; ln -sf libkmediaplayer.so.4.1.0 libkmediaplayer.so.4 )
-( cd opt/kde/lib ; rm -rf libkhtml.so.5 )
-( cd opt/kde/lib ; ln -sf libkhtml.so.5.1.0 libkhtml.so.5 )
-( cd opt/kde/lib ; rm -rf libkdnssd.so.4 )
-( cd opt/kde/lib ; ln -sf libkdnssd.so.4.1.0 libkdnssd.so.4 )
-( cd opt/kde/lib ; rm -rf libkfile.so.4 )
-( cd opt/kde/lib ; ln -sf libkfile.so.4.1.0 libkfile.so.4 )
-( cd opt/kde/lib ; rm -rf libkdecore.so.5 )
-( cd opt/kde/lib ; ln -sf libkdecore.so.5.1.0 libkdecore.so.5 )
-( cd opt/kde/lib ; rm -rf libkio.so )
-( cd opt/kde/lib ; ln -sf libkio.so.5 libkio.so )
-( cd opt/kde/lib ; rm -rf libkpty.so )
-( cd opt/kde/lib ; ln -sf libkpty.so.4 libkpty.so )
+( cd opt/kde/lib ; rm -rf libplasma.so.3 )
+( cd opt/kde/lib ; ln -sf libplasma.so.3.0.0 libplasma.so.3 )
+( cd opt/kde/lib ; rm -rf libktexteditor.so )
+( cd opt/kde/lib ; ln -sf libktexteditor.so.4 libktexteditor.so )
+( cd opt/kde/lib ; rm -rf libkfile.so )
+( cd opt/kde/lib ; ln -sf libkfile.so.4 libkfile.so )
+( cd opt/kde/lib ; rm -rf libkdefakes.so.5 )
+( cd opt/kde/lib ; ln -sf libkdefakes.so.5.2.0 libkdefakes.so.5 )
 ( cd opt/kde/lib ; rm -rf libknotifyconfig.so.4 )
-( cd opt/kde/lib ; ln -sf libknotifyconfig.so.4.1.0 libknotifyconfig.so.4 )
+( cd opt/kde/lib ; ln -sf libknotifyconfig.so.4.2.0 libknotifyconfig.so.4 )
+( cd opt/kde/lib ; rm -rf libkimproxy.so.4 )
+( cd opt/kde/lib ; ln -sf libkimproxy.so.4.2.0 libkimproxy.so.4 )
+( cd opt/kde/lib ; rm -rf libplasma.so )
+( cd opt/kde/lib ; ln -sf libplasma.so.3 libplasma.so )
+( cd opt/kde/lib ; rm -rf libkparts.so.4 )
+( cd opt/kde/lib ; ln -sf libkparts.so.4.2.0 libkparts.so.4 )
+( cd opt/kde/lib ; rm -rf libkrosscore.so.4 )
+( cd opt/kde/lib ; ln -sf libkrosscore.so.4.2.0 libkrosscore.so.4 )
+( cd opt/kde/lib ; rm -rf libkrosscore.so )
+( cd opt/kde/lib ; ln -sf libkrosscore.so.4 libkrosscore.so )
+( cd opt/kde/lib ; rm -rf libkntlm.so.4 )
+( cd opt/kde/lib ; ln -sf libkntlm.so.4.2.0 libkntlm.so.4 )
+( cd opt/kde/lib ; rm -rf libkdecore.so )
+( cd opt/kde/lib ; ln -sf libkdecore.so.5 libkdecore.so )
+( cd opt/kde/lib ; rm -rf libkmediaplayer.so )
+( cd opt/kde/lib ; ln -sf libkmediaplayer.so.4 libkmediaplayer.so )
+( cd opt/kde/lib ; rm -rf libkutils.so )
+( cd opt/kde/lib ; ln -sf libkutils.so.4 libkutils.so )
+( cd opt/kde/lib ; rm -rf libkdnssd.so )
+( cd opt/kde/lib ; ln -sf libkdnssd.so.4 libkdnssd.so )
+( cd opt/kde/lib ; rm -rf libsolid.so )
+( cd opt/kde/lib ; ln -sf libsolid.so.4 libsolid.so )
+( cd opt/kde/lib ; rm -rf libkdefakes.so )
+( cd opt/kde/lib ; ln -sf libkdefakes.so.5 libkdefakes.so )
+( cd opt/kde/lib ; rm -rf libkmediaplayer.so.4 )
+( cd opt/kde/lib ; ln -sf libkmediaplayer.so.4.2.0 libkmediaplayer.so.4 )
+( cd opt/kde/lib ; rm -rf libkunittest.so )
+( cd opt/kde/lib ; ln -sf libkunittest.so.4 libkunittest.so )
 ( cd opt/kde/lib ; rm -rf libkjsapi.so )
 ( cd opt/kde/lib ; ln -sf libkjsapi.so.4 libkjsapi.so )
-( cd opt/kde/lib ; rm -rf libkjsapi.so.4 )
-( cd opt/kde/lib ; ln -sf libkjsapi.so.4.1.0 libkjsapi.so.4 )
+( cd opt/kde/lib ; rm -rf libkntlm.so )
+( cd opt/kde/lib ; ln -sf libkntlm.so.4 libkntlm.so )
+( cd opt/kde/lib ; rm -rf libkde3support.so.4 )
+( cd opt/kde/lib ; ln -sf libkde3support.so.4.2.0 libkde3support.so.4 )
+( cd opt/kde/lib ; rm -rf libktexteditor.so.4 )
+( cd opt/kde/lib ; ln -sf libktexteditor.so.4.2.0 libktexteditor.so.4 )
+( cd opt/kde/lib ; rm -rf libsolid.so.4 )
+( cd opt/kde/lib ; ln -sf libsolid.so.4.2.0 libsolid.so.4 )
+( cd opt/kde/lib ; rm -rf libkpty.so.4 )
+( cd opt/kde/lib ; ln -sf libkpty.so.4.2.0 libkpty.so.4 )
+( cd opt/kde/lib ; rm -rf libkpty.so )
+( cd opt/kde/lib ; ln -sf libkpty.so.4 libkpty.so )
+( cd opt/kde/lib ; rm -rf libkhtml.so )
+( cd opt/kde/lib ; ln -sf libkhtml.so.5 libkhtml.so )
+( cd opt/kde/lib ; rm -rf libkio.so.5 )
+( cd opt/kde/lib ; ln -sf libkio.so.5.2.0 libkio.so.5 )
+( cd opt/kde/share/doc/HTML/en/kioslave/ftp ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/ftp ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/data ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/data ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/file ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/file ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/help ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/help ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/http ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/http ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/mailto ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/mailto ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/rlogin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/rlogin ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/telnet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/telnet ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/webdav ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/webdav ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/sonnet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/sonnet ; ln -sf /opt/kde/share/doc/HTML/en/common common )
